# arpes.plotting.qt\_tool.BinningInfoWidget module

**class
arpes.plotting.qt\_tool.BinningInfoWidget.BinningInfoWidget(parent=None,
root=None, axis\_index=None)**

> Bases: `PyQt5.QtWidgets.QGroupBox`
> 
> **changeBinning()**
> 
> **recompute()**
